@@ -22,42 +22,40 @@
 #'
 #' @section dot-options:
 #'
-#' \describe{
-#'   \item{new-package}{ enable checks specific to new packages}
-#'   \item{no-check-dependencies}{ disable check for bad dependencies}
-#'   \item{no-check-deprecated}{ disable check for usage of deprecated packages}
-#'   \item{no-check-remotes}{ disable check for usage of remote packages other
-#'     than those hosted on CRAN or Bioconductor}
-#'   \item{no-check-version-num}{ disable check for valid version number}
-#'   \item{no-check-R-ver}{ disable check for valid R version}
-#'   \item{no-check-pkg-size}{ disable check for package tarball size}
-#'   \item{no-check-file-size}{ disable check for individual file size}
-#'   \item{no-check-bioc-views}{ disable biocViews-specific checks (for non-BioC
-#'     packages)}
-#'   \item{no-check-bbs}{ disable BBS-specific checks (for non-BioC packages).
-#'     Valid DESCRIPTION}
-#'   \item{no-check-description}{ disable DESCRIPTION file checks}
-#'   \item{no-check-vignettes}{ disable vignette checks}
-#'   \item{no-check-library-calls}{ disable check usage of functions that
-#'     install or update packages}
-#'   \item{no-check-install-self}{ disable check for require or library of
-#'     itself}
-#'   \item{no-check-coding-practices}{ disable check for some common best coding
-#'     practices}
-#'   \item{no-check-function-len}{ disable check for function length}
-#'   \item{no-check-man-doc}{ disable checks for man page documentation}
-#'   \item{no-check-news}{ disable checks for NEWS file}
-#'   \item{no-check-unit-tests}{ disable checks for unit tests}
-#'   \item{no-check-skip-bioc-tests}{ disable check for tests that skip when on
-#'     bioc}
-#'   \item{no-check-formatting}{ disable checks for file formatting}
-#'   \item{no-check-CRAN}{ disable check for if package exists in CRAN}
-#'   \item{no-check-bioc-help}{ disable check for registration on Bioconductor
-#'     mailing list and support site}
-#'   \item{build-output-file}{ file containing R CMD build output, for
-#'     additional analysis}
-#'   \item{quit-with-status}{ enable exit code option when performing check}
-#' }
+#'   * `new-package`:  enable checks specific to new packages
+#'   * `no-check-dependencies`:  disable check for bad dependencies
+#'   * `no-check-deprecated`:  disable check for usage of deprecated packages
+#'   * `no-check-remotes`: disable check for usage of remote packages other
+#'     than those hosted on CRAN or Bioconductor
+#'   * `no-check-version-num`:  disable check for valid version number
+#'   * `no-check-R-ver`:  disable check for valid R version
+#'   * `no-check-pkg-size`:  disable check for package tarball size
+#'   * `no-check-file-size`:  disable check for individual file size
+#'   * `no-check-bioc-views`: disable biocViews-specific checks (for non-BioC
+#'     packages)
+#'   * `no-check-bbs`: disable BBS-specific checks (for non-BioC packages).
+#'     Valid DESCRIPTION
+#'   * `no-check-description`:  disable DESCRIPTION file checks
+#'   * `no-check-vignettes`:  disable vignette checks
+#'   * `no-check-library-calls`: disable check usage of functions that
+#'     install or update packages
+#'   * `no-check-install-self`: disable check for require or library of
+#'     itself
+#'   * `no-check-coding-practices`: disable check for some common best coding
+#'     practices
+#'   * `no-check-function-len`:  disable check for function length
+#'   * `no-check-man-doc`:  disable checks for man page documentation
+#'   * `no-check-news`:  disable checks for NEWS file
+#'   * `no-check-unit-tests`:  disable checks for unit tests
+#'   * `no-check-skip-bioc-tests`: disable check for tests that skip when on
+#'     bioc
+#'   * `no-check-formatting`:  disable checks for file formatting
+#'   * `no-check-CRAN`:  disable check for if package exists in CRAN
+#'   * `no-check-bioc-help`: disable check for registration on Bioconductor
+#'     mailing list and support site
+#'   * `build-output-file`: file containing R CMD build output, for
+#'     additional analysis
+#'   * `quit-with-status`:  enable exit code option when performing check
 #'
 #' @param package The path to an R package directory or tarball (`.tar.gz`).
 #'   The `BiocCheck` function is intended to be run from the package
@@ -84,21 +82,17 @@
 #'   reporting. The function also creates a `<package_name>.BiocCheck` folder
 #'   and returns a `BiocCheck` reference class with three main list elements:
 #'
-#' \item{error}{Items to address before the package can be accepted}
+#' * **error**: Items to address before the package can be accepted
 #'
-#' \item{warning}{Strongly suggested items that may require attention}
+#' * **warning**: Strongly suggested items that may require attention
 #'
-#' \item{note}{Items to consider, though not required, before acceptance}
+#' * **note**: Items to consider, though not required, before acceptance
 #'
 #' @author Dan Tenenbaum, Lori Shepherd, and Marcel Ramos
 #'
-#' @md
-#'
 #' @references \url{https://contributions.bioconductor.org}
 #' @seealso \link{BiocCheck-class}, \link{Message-class}
 #'
-#' @importFrom utils untar
-#'
 #' @examples
 #'
 #' packageDir <- system.file("testpackages", "testpkg0", package="BiocCheck")
@@ -128,15 +122,14 @@ BiocCheck <- function(
     }
 }
 
+#' @importFrom BiocBaseUtils isScalarCharacter
 BiocCheckRun <-
     function(package, checkDir, debug, ...)
 {
-    .zeroCounters()
+    .BiocCheck$zero()
     package <- normalizePath(package)
-    if (!file.exists(package))
-        .stop("Package directory or tarball does not exist.")
-    if (!length(package))
-        .stop("Supply a package directory or source tarball.")
+    if (!file.exists(package) || !isScalarCharacter(package))
+        .stop("Package directory or tarball provided does not exist.")
     # be careful here:
     if (identical(.Platform$OS.type, "windows"))
         package <- gsub("\\\\", "/", package)
@@ -146,75 +139,72 @@ BiocCheckRun <-
         dots <- dots[[1]]               # command line args come as list
 
     oldwarn <- getOption("warn")
-    on.exit(options(warn=oldwarn))
-    options(warn=1)
+    oldwidth <- getOption("cli.width")
+    on.exit({
+        options(warn = oldwarn, cli.width = oldwidth)
+    })
+    options(warn = 1, cli.width = 80)
 
-    isTar <- grepl("\\.tar\\.gz$", package)
-    checkingDir <- !isTar && file.info(package)[["isdir"]]
-    package_dir <- .getPackageDir(package, isTar)
-    package_name <- .getPackageName(package)
-    package_install_dir <- installAndLoad(package)
+    .BiocPackage <- .BiocPackage$initialize(
+        packageDir = package, checkDir = checkDir
+    )
+
+    ## consider merging these operations into one
+    cli::cli_div(theme = list(.pkg = list(color = "orange")))
+    cli::cli_rule("Installing {.pkg { .BiocPackage$packageName }}")
+    package_install_dir <- installAndLoad(.BiocPackage)
+    cli::cli_alert_success("Package installed successfully")
     libloc <- file.path(package_install_dir, "lib")
-    pkgver <- .getPackageVersion(package_dir)
-    bioccheckver <- as.character(packageVersion("BiocCheck"))
-    biocver <- as.character(BiocManager::version())
-    checkDir <- .getBiocCheckDir(package_name, checkDir)
     isBBS <- Sys.getenv("IS_BIOC_BUILD_MACHINE")
     onBBS <- nzchar(isBBS) && identical(tolower(isBBS), "true")
     hasAdmin <- nzchar(Sys.getenv("BIOC_DEVEL_PASSWORD"))
 
-    .BiocCheck$metadata <- list(
-        BiocCheckVersion = bioccheckver,
-        BiocVersion = biocver,
-        Package = package_name, PackageVersion = pkgver,
-        sourceDir = package_dir, installDir = package_install_dir,
-        BiocCheckDir = checkDir,
-        platform = .Platform$OS.type, isTarBall = isTar
+    .BiocCheck$addMetadata(
+        BiocPackage = .BiocPackage, installDir = package_install_dir
     )
+    cli::cli_rule("{.pkg { .BiocPackage$packageName }} session metadata")
     .BiocCheck$show_meta()
-
-    handleMessage("* Installing package...", indent = 0, exdent = 0)
+    cli::cli_rule("Running BiocCheck on {.pkg { .BiocPackage$packageName }}")
 
     # BiocCheck checks --------------------------------------------------------
-    if (is.null(dots[["no-check-deprecated"]])){
+    if (is.null(dots[["no-check-deprecated"]])) {
         handleCheck("Checking for deprecated package usage...")
-        checkDeprecatedPackages(package_dir)
+        checkDeprecatedPackages(.BiocPackage)
     }
 
     if (is.null(dots[["no-check-remotes"]])){
         handleCheck("Checking for remote package usage...")
-        checkRemotesUsage(package_dir)
+        checkRemotesUsage(.BiocPackage)
     }
 
     handleCheck("Checking for 'LazyData: true' usage...")
-    checkLazyDataUsage(package_dir)
+    checkLazyDataUsage(.BiocPackage)
 
     if (is.null(dots[["no-check-version-num"]])){
         handleCheck("Checking version number...")
-        if (!checkingDir) {
+        if (!.BiocPackage$isSourceDir) {
             handleCheck("Checking for version number mismatch...")
-            checkForVersionNumberMismatch(package, package_dir)
+            checkForVersionNumberMismatch(.BiocPackage)
         }
 
         if (!is.null(dots[["new-package"]])) {
             handleCheck("Checking new package version number...")
-            checkNewPackageVersionNumber(package_dir)
+            checkNewPackageVersionNumber(.BiocPackage)
         } else {
             handleCheck("Checking version number validity...")
-            checkVersionNumber(package_dir)
+            checkVersionNumber(.BiocPackage)
         }
     }
 
     if (is.null(dots[["no-check-R-ver"]])) {
         handleCheck("Checking R version dependency...")
-        checkRVersionDependency(package_dir)
+        checkRVersionDependency(.BiocPackage)
     }
 
-    source_tarball <- grepl("\\.tar\\.gz$", package)
     if (is.null(dots[["no-check-pkg-size"]])){
         handleCheck("Checking package size...")
-        if (source_tarball){
-            checkPackageSize(package, package_dir, size=5)
+        if (.BiocPackage$isTar){
+            checkPackageSize(.BiocPackage, size=5)
         } else {
             handleMessage("Skipped... only checked on source tarball", indent=4)
         }
@@ -222,69 +212,71 @@ BiocCheckRun <-
 
     if (is.null(dots[["no-check-file-size"]])){
         handleCheck("Checking individual file sizes...")
-        checkIndivFileSizes(package_dir)
-        checkDataFileSizes(package_dir)
+        checkIndivFileSizes(.BiocPackage)
+        checkDataFileSizes(.BiocPackage)
     }
 
     if (is.null(dots[["no-check-bioc-views"]]))
     {
         handleCheck("Checking biocViews...")
-        result <- checkBiocViews(package_dir)
+        result <- checkBiocViews(.BiocPackage)
         if(result)
         {
-            .msg("Search 'biocViews' at https://contributions.bioconductor.org")
+            cli::cli_alert_info(
+                "Search 'biocViews' at https://contributions.bioconductor.org"
+            )
         }
     }
 
     if (is.null(dots[["no-check-bbs"]])){
         handleCheck("Checking build system compatibility...")
-        checkBBScompatibility(package_dir, source_tarball)
+        checkBBScompatibility(.BiocPackage)
     }
 
     if (is.null(dots[["no-check-description"]])) {
-        ## the following is redundant with other outputs...
-        ## handleCheck("Checking DESCRIPTION file...")
-        checkDESCRIPTIONFile(package_dir)
+        checkDESCRIPTIONFile(.BiocPackage)
     }
 
     handleCheck("Checking .Rbuildignore...")
-    checkRbuildignore(package_dir)
+    checkRbuildignore(.BiocPackage)
 
     handleCheck("Checking for stray BiocCheck output folders...")
-    checkBiocCheckOutputFolder(package_dir, package_name)
+    checkBiocCheckOutputFolder(.BiocPackage)
 
-    if (!isTar) {
+    if (!.BiocPackage$isTar) {
         handleCheck("Checking for inst/doc folders...")
-        checkInstDocFolder(package_dir, package_name)
+        checkInstDocFolder(.BiocPackage)
     }
 
     if (is.null(dots[["no-check-vignettes"]])) {
         handleCheck("Checking vignette directory...")
-        checkVignetteDir(package_dir, checkingDir)
+        checkVignetteDir(.BiocPackage)
         if ("build-output-file" %in% names(dots)) {
             handleCheck(
                 "Checking whether vignette is built with 'R CMD build'..."
             )
-            checkIsVignetteBuilt(package_dir, dots[["build-output-file"]])
+            checkIsVignetteBuilt(dots[["build-output-file"]])
         }
     }
 
     if (is.null(dots[["no-check-library-calls"]])){
         handleCheck("Checking package installation calls in R code...")
-        checkPkgInstallCalls(package_dir)
+        checkPkgInstallCalls(.BiocPackage)
     }
 
-    parsedCode <- parseFiles(package_dir)
+    package_dir <- .BiocPackage$sourceDir
+    package_name <- .BiocPackage$packageName
+    parsedCode <- parseFiles(.BiocPackage)
 
     if (is.null(dots[["no-check-install-self"]])){
         handleCheck(sprintf("Checking for library/require of %s...",
                             package_name))
-        checkForLibraryRequire(package_dir)
+        checkForLibraryRequire(.BiocPackage)
     }
 
     if (is.null(dots[["no-check-coding-practices"]])){
         handleCheck("Checking coding practice...")
-        checkCodingPractice(package_dir, parsedCode, package_name)
+        checkCodingPractice(.BiocPackage, parsedCode)
     }
 
     if (is.null(dots[["no-check-function-len"]])){
@@ -294,7 +286,7 @@ BiocCheckRun <-
 
     if (is.null(dots[["no-check-man-doc"]])){
         handleCheck("Checking man page documentation...")
-        checkManDocumentation(package_dir, package_name, libloc)
+        checkManDocumentation(.BiocPackage, libloc)
     }
 
     if (is.null(dots[["no-check-news"]])){
@@ -316,7 +308,7 @@ BiocCheckRun <-
         handleCheck(
             "Checking formatting of DESCRIPTION, NAMESPACE, ",
             "man pages, R source, and vignette source...")
-        checkFormatting(package_dir)
+        checkFormatting(.BiocPackage)
     }
 
     if (is.null(dots[["no-check-CRAN"]]))
@@ -339,7 +331,7 @@ BiocCheckRun <-
     if (is.null(dots[["no-check-bioc-help"]])) {
         handleCheck("Checking for bioc-devel mailing list subscription...")
         if (hasAdmin) {
-            checkForBiocDevelSubscription(package_dir)
+            checkForBiocDevelSubscription(.BiocPackage)
         } else {
             handleNote(
                 "Cannot determine whether maintainer is subscribed to the ",
@@ -350,21 +342,25 @@ BiocCheckRun <-
         }
 
         handleCheck("Checking for support site registration...")
-        checkForSupportSiteRegistration(package_dir)
+        checkForSupportSiteRegistration(.BiocPackage)
     }
 
-    # BiocCheck results -------------------------------------------------------
-    message("\n\U2500 BiocCheck results \U2500\U2500")
-    .msg(
-        "%d ERRORS | %d WARNINGS | %d NOTES",
-        .BiocCheck$getNum("error"),
-        .BiocCheck$getNum("warning"),
-        .BiocCheck$getNum("note")
+    cli::cli_rule(
+        left = paste0("BiocCheck v", packageVersion("BiocCheck"), " results")
     )
-    message(
-        "\nSee the ", package_name, ".BiocCheck folder and run\n",
-        "    browseVignettes(package = 'BiocCheck')\n",
-        "for details."
+    cli::cli_text(
+        paste0(
+            "{symbol$cross} { .BiocCheck$getNum('error') } ERRORS | ",
+            "{symbol$warning} { .BiocCheck$getNum('warning') } WARNINGS | ",
+            "{symbol$bullet} { .BiocCheck$getNum('note') } NOTES\n"
+        )
+    )
+    cli::cli_alert_info(
+        paste0(
+            "\nSee the { .BiocPackage$packageName }.BiocCheck folder and run\n",
+            "  browseVignettes(package = 'BiocCheck')\n",
+            "  for details."
+        )
     )
 
     .BiocCheck$report(debug, onBBS)
@@ -377,57 +373,3 @@ BiocCheckRun <-
     return(.BiocCheck)
 
 }
-
-# input can either be tarball or pkg source dir
-.getPackageName <- function(input)
-{
-    isTar <- grepl("\\.tar\\.gz$", input)
-    if (isTar) {
-        tmp_pkg_dir <- .tempPackageDirTarball(input)
-        on.exit({
-            unlink(dirname(tmp_pkg_dir), recursive = TRUE)
-        })
-        desc <- file.path(tmp_pkg_dir, "DESCRIPTION")
-        if (!file.exists(desc))
-            .stop("The package folder is inconsistent with the tarball name.")
-    } else {
-        desc <- file.path(input, "DESCRIPTION")
-    }
-    read.dcf(desc, fields = "Package")[[1]]
-}
-
-.tempPackageDirTarball <- function(pkg_tarball)
-{
-    tmp_dir <- tempfile()
-    pkg_name <- gsub("(\\w+)_.*", "\\1", basename(pkg_tarball))
-    if (!dir.exists(tmp_dir))
-        dir.create(tmp_dir)
-    suppressMessages({
-        untar(pkg_tarball, exdir = tmp_dir)
-    })
-    # pkg_name must match with tarred folder
-    file.path(tmp_dir, pkg_name)
-}
-
-.getPackageDir <- function(input, isTar) {
-    if (isTar) {
-        .tempPackageDirTarball(input)
-    } else {
-        if (file.info(input)[["isdir"]])
-            input
-        else
-            .stop("'%s' is not a directory or package source tarball.", input)
-    }
-}
-
-.getBiocCheckDir <- function(pkgName, checkDir) {
-    checkDir <- normalizePath(checkDir, winslash = "/")
-    file.path(
-        checkDir, paste(pkgName, "BiocCheck", sep = ".")
-    )
-}
-
-.getPackageVersion <- function(pkgdir) {
-    desc <- file.path(pkgdir, "DESCRIPTION")
-    as.character(read.dcf(desc, fields = "Version"))
-}
